"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _keys = require("babel-runtime/core-js/object/keys");

var _keys2 = _interopRequireDefault(_keys);

exports.default = envOverride;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Given an object, this function will override the values of each top level
 * field with the corresponding env variable if it exists.
 *
 * eg.
 *
 * FOO_BAR=bar node index.js
 *
 * contents of index.js:
 *
 * const config = envOverride({ FOO_BAR: 'hi' })
 * config.FOO_BAR === 'bar'
 *
 *
 * note: keys must match env var there will be no case conversion eg. fooBar !== FOO_BAR
 *
 * @param {object} obj
 * @returns {object}
 */
function envOverride(obj) {
  var modifiedObj = {};

  var keys = (0, _keys2.default)(obj);
  for (var i = 0; i < keys.length; i++) {
    modifiedObj[keys[i]] = process.env[keys[i]] || obj[keys[i]];
  }

  return modifiedObj;
}